========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/os-vif.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

======
os-vif
======

.. image:: https://img.shields.io/pypi/v/os-vif.svg
    :target: https://pypi.org/project/os-vif/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/os-vif.svg
    :target: https://pypi.org/project/os-vif/
    :alt: Downloads

A library for plugging and unplugging virtual interfaces in OpenStack.

* License: Apache License, Version 2.0
* Documentation: https://docs.openstack.org/os-vif/latest/
* Source: https://opendev.org/openstack/os-vif
* Bugs: https://bugs.launchpad.net/os-vif
* Release Notes: https://docs.openstack.org/releasenotes/os-vif
